@@ -2,13 +2,19 @@ import getopt
 import os
 import sys
 
+import logger
+
 from inspector import inspect_project
 from generator import add_tests_to_project, UnknownTemplate
+from logger import log
 from store import Project, ModuleNotFound, ModuleNeedsAnalysis, \
      ModuleSaveError, get_pythoscope_path, get_points_of_entry_path
 from util import samefile
 
 
+__version__ = '0.3.2'
+
+BUGTRACKER_URL = "https://bugs.launchpad.net/pythoscope"
 USAGE = """Pythoscope usage:
 
     %s [options] [module names...]
@@ -45,6 +51,9 @@ Options:
   -t TEMPLATE_NAME, --template=TEMPLATE_NAME
                  Name of a template to use (see below for a list of
                  available templates). Default is "unittest".
+  -q, --quiet    Don't print anything unless it's an error.
+  -v, --verbose  Be very verbose (basically enable debug output).
+  -V, --version  Print Pythoscope version and exit.
 
 Available templates:
   * unittest     All tests are placed into classes which derive from
@@ -83,10 +92,11 @@ def init_project(path):
     pythoscope_path = get_pythoscope_path(path)
 
     try:
+        log.debug("Initializing .pythoscope directory: %s" % (os.path.abspath(pythoscope_path)))
         os.makedirs(pythoscope_path)
         os.makedirs(get_points_of_entry_path(path))
     except OSError, err:
-        print "Error: Couldn't initialize Pythoscope directory: %s." % err.strerror
+        log.error("Couldn't initialize Pythoscope directory: %s." % err.strerror)
 
 def generate_tests(modules, force, template):
     try:
@@ -95,33 +105,37 @@ def generate_tests(modules, force, template):
         add_tests_to_project(project, modules, template, force)
         project.save()
     except PythoscopeDirectoryMissing:
-        print "Error: Can't find .pythoscope/ directory for this project. " \
-              "Initialize the project with the '--init' option first."
+        log.error("Can't find .pythoscope/ directory for this project. "
+                  "Initialize the project with the '--init' option first.")
     except ModuleNeedsAnalysis, err:
         if err.out_of_sync:
-            print "Error: Tried to generate tests for test module located at %r, " \
-                  "but it has been modified during this run. Please try running pythoscope again." % err.path
+            log.error("Tried to generate tests for test module located at %r, "
+                      "but it has been modified during this run. Please try "
+                      "running pythoscope again." % err.path)
         else:
-            print "Error: Tried to generate tests for test module located at %r, " \
-                  "but it was created during this run. Please try running pythoscope again." % err.path
+            log.error("Tried to generate tests for test module located at %r, "
+                      "but it was created during this run. Please try running "
+                      "pythoscope again." % err.path)
     except ModuleNotFound, err:
         if os.path.exists(err.module):
-            print "Error: Couldn't find information on module %r. This shouldn't happen, please file a bug report." % err.module
+            log.error("Couldn't find information on module %r. This shouldn't "
+                      "happen, please file a bug report at %s." % (err.module, BUGTRACKER_URL))
         else:
-            print "Error: File doesn't exist: %s." % err.module
+            log.error("File doesn't exist: %s." % err.module)
     except ModuleSaveError, err:
-        print "Error: Couldn't save module %r: %s." % (err.module, err.reason)
+        log.error("Couldn't save module %r: %s." % (err.module, err.reason))
     except UnknownTemplate, err:
-        print "Error: Couldn't find template named %r. Available templates are 'nose' and 'unittest'." % err.template
+        log.error("Couldn't find template named %r. Available templates are "
+                  "'nose' and 'unittest'." % err.template)
 
 def main():
     appname = os.path.basename(sys.argv[0])
 
     try:
-        options, args = getopt.getopt(sys.argv[1:], "fhit:",
-                                      ["force", "help", "init", "template="])
+        options, args = getopt.getopt(sys.argv[1:], "fhit:qvV",
+                        ["force", "help", "init", "template=", "quiet", "verbose", "version"])
     except getopt.GetoptError, err:
-        print "Error:", err, "\n"
+        log.error("Error: %s\n" % err)
         print USAGE % appname
         sys.exit(1)
 
@@ -139,6 +153,13 @@ def main():
             init = True
         elif opt in ("-t", "--template"):
             template = value
+        elif opt in ("-q", "--quiet"):
+            log.level = logger.ERROR
+        elif opt in ("-v", "--verbose"):
+            log.level = logger.DEBUG
+        elif opt in ("-V", "--version"):
+            print "%s %s" % (appname, __version__)
+            sys.exit()
 
     try:
         if init:
@@ -149,11 +170,10 @@ def main():
             init_project(project_path)
         else:
             if not args:
-                print "Error: You didn't specify any module to generate tests for.\n"
+                log.error("You didn't specify any modules for test generation.\n")
                 print USAGE % appname
             else:
                 generate_tests(args, force, template)
     except:
-        print "Ups, it seems internal Pythoscope error occured. Please file a bug report at https://bugs.launchpad.net/pythoscope"
-        print
+        log.error("Oops, it seems internal Pythoscope error occured. Please file a bug report at %s\n" % BUGTRACKER_URL)
         raise
