@@ -1,4 +1,5 @@
 from pythoscope.inspector import static, dynamic
+from pythoscope.logger import log
 from pythoscope.store import ModuleNotFound
 from pythoscope.util import python_modules_below
 
@@ -14,7 +15,7 @@ def inspect_project(project):
     if updates:
         inspect_project_dynamically(project)
     else:
-        print "Info: No changes discovered in the source code, skipping dynamic inspection."
+        log.info("No changes discovered in the source code, skipping dynamic inspection.")
 
 def remove_deleted_modules(project):
     subpaths = [mod.subpath for mod in project.iter_modules() if not mod.exists()]
@@ -27,10 +28,11 @@ def add_and_update_modules(project):
         try:
             module = project.find_module_by_full_path(modpath)
             if module.is_up_to_date():
-                print "Info: %s hasn't changed since last inspection, skipping." % module.subpath
+                log.info("%s hasn't changed since last inspection, skipping." % module.subpath)
                 continue
         except ModuleNotFound:
             pass
+        log.info("Inspecting module %s." % project._extract_subpath(modpath))
         static.inspect_module(project, modpath)
         count += 1
     return count
@@ -51,8 +53,9 @@ def add_and_update_points_of_entry(project):
 def inspect_project_dynamically(project):
     for poe in project.points_of_entry.values():
         try:
+            log.info("Inspecting point of entry %s." % poe.name)
             dynamic.inspect_point_of_entry(poe)
         except SyntaxError, err:
-            print "Warning: Point of entry contains a syntax error:", err
+            log.warning("Point of entry contains a syntax error: %s" % err)
         except (Exception, KeyboardInterrupt, SystemExit), err:
-            print "Warning: Point of entry exited with error:", repr(err)
+            log.warning("Point of entry exited with error: %s" % repr(err))
