@@ -3,12 +3,15 @@ import os
 import re
 import types
 
+from StringIO import StringIO
+
 from fixture import TempIO
 from nose.tools import assert_equal
 
 from pythoscope.generator import add_tests_to_project
+from pythoscope.logger import get_output, set_output
 from pythoscope.store import Function, ModuleNotFound, PointOfEntry, Project
-from pythoscope.util import read_file_contents, set
+from pythoscope.util import quoted_block, read_file_contents, set
 
 
 UNPICKABLE_OBJECT = types.ClassType('class', (), {})
@@ -26,9 +29,6 @@ def P(path):
     "Convert given path with slashes to proper format for OS we're running on."
     return os.path.join(*path.split("/"))
 
-def quoted_block(text):
-    return ''.join(["> %s" % line for line in text.splitlines(True)])
-
 def assert_length(collection, expected_length):
     actual_length = len(collection)
     assert expected_length == actual_length,\
@@ -73,6 +73,10 @@ def assert_instance(object, type):
            "Expected object %r to be of type %r, it was of type %r instead." % \
            (object, type, type(object))
 
+def assert_matches(regexp, string):
+    assert re.match(regexp, string), \
+        "Expected\n%s\nto match r'%s', but it didn't." % (quoted_block(string), regexp)
+
 class PointOfEntryMock(PointOfEntry):
     def __init__(self, project=None, name="poe", content=""):
         if project is None:
@@ -86,16 +90,6 @@ class PointOfEntryMock(PointOfEntry):
     def get_content(self):
         return self.content
 
-# Make your test case a subclass of CustomSeparator to test your code with
-# alternative os.path.sep.
-class CustomSeparator:
-    def setUp(self):
-        self.old_sep = os.path.sep
-        os.path.sep = '#'
-
-    def tearDown(self):
-        os.path.sep = self.old_sep
-
 def EmptyProject():
     project = Project(path=os.path.realpath("."))
     # Preserve the default value.
@@ -122,6 +116,13 @@ def ProjectWithRealModules(paths):
         project.path.putfile(path, "")
     return project
 
+def ProjectWithPointsOfEntryFiles(paths):
+    project = ProjectInDirectory()
+    project.path.mkdir(P(".pythoscope/points-of-entry"))
+    for path in paths:
+        project.path.putfile(os.path.join(P(".pythoscope/points-of-entry"), path), "")
+    return project
+
 def TestableProject(more_modules=[], project_type=ProjectInDirectory):
     project = ProjectWithModules(["module.py"] + more_modules, project_type)
     project["module"].objects = [Function("function")]
@@ -148,3 +149,32 @@ generate_single_test_module.__test__ = False
 def get_test_cases(project):
     return list(project.iter_test_cases())
 get_test_cases.__test__ = False
+
+###############################################################################
+# Test superclasses
+#   Subclass one of those to get a desired test fixture.
+
+class CustomSeparator:
+    """Subclass CustomSeparator to test your code with alternative os.path.sep.
+    """
+    def setUp(self):
+        self.old_sep = os.path.sep
+        os.path.sep = '#'
+
+    def tearDown(self):
+        os.path.sep = self.old_sep
+
+class CapturedLogger:
+    """Capture all log output and make it available to test via
+    _get_log_output() method.
+    """
+    def setUp(self):
+        self._old_output = get_output()
+        self.captured = StringIO()
+        set_output(self.captured)
+
+    def tearDown(self):
+        set_output(self._old_output)
+
+    def _get_log_output(self):
+        return self.captured.getvalue()
