@@ -9,13 +9,13 @@ from pythoscope.generator import add_tests_to_project
 from pythoscope.store import Project, Class, Method, Function, \
      ModuleNeedsAnalysis, ModuleSaveError, TestClass, TestMethod, \
      MethodCall, FunctionCall, LiveObject, wrap_call_arguments, \
-     wrap_object, PointOfEntry, GeneratorObject
+     wrap_object, PointOfEntry, GeneratorObject, Value, Type
 from pythoscope.util import read_file_contents, get_last_modification_time
 
 from helper import assert_contains, assert_doesnt_contain, assert_length,\
-     generate_single_test_module, ProjectInDirectory, \
+     generate_single_test_module, P, ProjectInDirectory, \
      ProjectWithModules, TestableProject, assert_contains_once, \
-     PointOfEntryMock, get_test_cases, assert_equal_sets
+     PointOfEntryMock, get_test_cases, assert_equal_sets, CapturedLogger
 
 # Let nose know that those aren't test functions/classes.
 add_tests_to_project.__test__ = False
@@ -283,6 +283,21 @@ class TestGenerator:
         assert_contains(result, "something = Something(arg1=1, arg2=2)")
         assert_contains(result, "self.assertEqual(3, something.sum())")
 
+    def test_generates_nice_name_for_tests_with_init_that_takes_no_arguments(self):
+        klass = ClassWithMethods('Something', [('__init__', [({}, None)]),
+                                               ('fire', [({}, 'kaboom')])])
+
+        result = generate_single_test_module(objects=[klass])
+
+        assert_contains(result, "def test_fire_returns_kaboom(self):")
+
+    def test_generates_nice_name_for_tests_with_init_only_that_takes_no_arguments(self):
+        klass = ClassWithMethods('Something', [('__init__', [({}, None)])])
+
+        result = generate_single_test_module(objects=[klass])
+
+        assert_contains(result, "def test_creation(self):")
+
     def test_ignores_internal_object_calls(self):
         klass = ClassWithMethods('Something', [('method', [({'argument': 1}, 'result')])])
         live_object = klass.live_objects[('poe', 12345)]
@@ -360,6 +375,17 @@ class TestGenerator:
         assert_contains(result, "something = Something()")
         assert_contains(result, "self.assertRaises(KeyError, lambda: something.method())")
 
+    def test_generates_imports_for_user_defined_exceptions(self):
+        # Cheating a bit, as UserDefinedException class is not the same as one
+        # presumably defined in module.py.
+        class UserDefinedException(Exception): pass
+        function = Function('throw')
+        function.calls = [FunctionCall(None, function, {}, exception=Type(UserDefinedException()))]
+
+        result = generate_single_test_module(objects=[function])
+
+        assert_contains(result, "from test.test_generator import UserDefinedException")
+
     def test_generates_assert_equal_type_for_functions_returning_functions(self):
         objects = [FunctionWithSingleCall('higher', {}, lambda: 42)]
 
@@ -500,6 +526,23 @@ class TestGenerator:
         assert_doesnt_contain(result, "assertEqual")
         assert_doesnt_contain(result, "assertRaises")
 
+    def test_handles_unicode_objects(self):
+        objects = [FunctionWithSingleCall('characterize', {'x': u'\xf3'}, "o-acute")]
+
+        result = generate_single_test_module(objects=objects)
+
+        assert_contains(result, "def test_characterize_returns_oacute_for_unicode_string(self):")
+        assert_contains(result, "self.assertEqual('o-acute', characterize(x=u'\\xf3'))")
+
+    def test_handles_pickable_function_objects(self):
+        objects = [FunctionWithSingleCall('store', {'fun': read_file_contents}, None)]
+
+        result = generate_single_test_module(objects=objects)
+
+        assert_contains(result, "from pythoscope.util import read_file_contents")
+        assert_contains(result, "def test_store_returns_None_for_read_file_contents_function(self):")
+        assert_contains(result, "self.assertEqual(None, store(fun=read_file_contents))")
+
 class TestGeneratorWithTestDirectoryAsFile:
     def setUp(self):
         self.project = TestableProject()
@@ -557,3 +600,41 @@ class TestGeneratorWithSingleModule:
 
         assert_length(self.project["test_module"].test_cases, 1)
         assert_length(self.project["test_other"].test_cases, 0)
+
+    def test_comments_assertions_with_user_objects_that_cannot_be_constructed(self):
+        # Cheating a bit, as Something class is not the same as one defined in
+        # module.py.
+        class Something(object): pass
+        klass = Class("Something")
+        instance = Something()
+
+        poe = PointOfEntryMock()
+        function = Function("nofun")
+        function.calls = [FunctionCall(poe, function, {'x': Value(instance)}, Value("something else"))]
+        self.project["module"].objects = [klass, function]
+
+        add_tests_to_project(self.project, ["module.py"], 'unittest', False)
+        result = self.project["test_module"].get_content()
+
+        assert_contains(result, "def test_nofun_returns_something_else_for_something_instance(self):")
+        assert_contains(result, "# self.assertEqual('something else', nofun(x=%r))" % instance)
+
+class TestGeneratorMessages(CapturedLogger):
+    def test_reports_each_module_it_generates_tests_for(self):
+        paths = ["first.py", "another.py", P("one/more.py")]
+        project = ProjectWithModules(paths)
+
+        add_tests_to_project(project, paths, 'unittest')
+
+        for path in paths:
+            assert_contains_once(self._get_log_output(),
+                                 "Generating tests for module %s." % path)
+
+    def test_reports_each_added_test_class(self):
+        objects = [Class('SomeClass', [Method('some_method')]), Function('some_function')]
+        generate_single_test_module(objects=objects)
+
+        assert_contains_once(self._get_log_output(),
+                             "Adding generated TestSomeClass to tests/test_module.py.")
+        assert_contains_once(self._get_log_output(),
+                             "Adding generated TestSomeFunction to tests/test_module.py.")
