@@ -2,13 +2,12 @@ from nose.tools import assert_equal
 
 from pythoscope.astvisitor import parse
 from pythoscope.store import Class, LiveObject, Module, PointOfEntry, \
-     TestClass, Project, module_path_to_test_path
+     TestClass, Project
 
 from helper import CustomSeparator, assert_length
 
 # Let nose know that those aren't test cases.
 TestClass.__test__ = False
-module_path_to_test_path.__test__ = False
 
 class TestModule:
     def test_can_add_test_cases_to_empty_modules(self):
@@ -22,12 +21,6 @@ class TestStoreWithCustomSeparator(CustomSeparator):
         module = Module(subpath="some#path.py", project=None)
         assert_equal("some.path", module.locator)
 
-    def test_module_path_to_test_path_uses_system_specific_path_separator(self):
-        assert_equal("test_pythoscope_store.py",
-                     module_path_to_test_path("pythoscope#store.py"))
-        assert_equal("test_pythoscope.py",
-                     module_path_to_test_path("pythoscope#__init__.py"))
-
 # Avoid a name clash with pythoscope.store.TestClass.
 class TestForClass:
     def test_remove_live_objects_from(self):
